@@ -1,6 +1,6 @@
 /*
- * POSIX library for Lua 5.1, 5.2 & 5.3.
- * Copyright (C) 2013-2019 Gary V. Vaughan
+ * POSIX library for Lua 5.1, 5.2, 5.3 & 5.4.
+ * Copyright (C) 2013-2021 Gary V. Vaughan
  * Copyright (C) 2010-2013 Reuben Thomas <rrt@sc3d.org>
  * Copyright (C) 2008-2010 Natanael Copa <natanael.copa@gmail.com>
  * Clean up and bug fixes by Leo Razoumov <slonik.az@gmail.com> 2006-10-11
@@ -84,7 +84,8 @@ Set a resource limit for subsequent child processes.
 @return[2] nil
 @treturn[2] string error message
 @treturn[2] int errnum
-@see getrlimit(2)
+@see setrlimit(2)
+@see getrlimit
 @see limit.lua
 @usage
   local sysres = require "posix.sys.resource"
