@@ -1,6 +1,6 @@
 /*
- * POSIX library for Lua 5.1, 5.2 & 5.3.
- * Copyright (C) 2013-2019 Gary V. Vaughan
+ * POSIX library for Lua 5.1, 5.2, 5.3 & 5.4.
+ * Copyright (C) 2013-2021 Gary V. Vaughan
  * Copyright (C) 2010-2013 Reuben Thomas <rrt@sc3d.org>
  * Copyright (C) 2008-2010 Natanael Copa <natanael.copa@gmail.com>
  * Clean up and bug fixes by Leo Razoumov <slonik.az@gmail.com> 2006-10-11
@@ -70,7 +70,10 @@ pushstatvfs(lua_State *L, struct statvfs *sv)
 Get file system statistics.
 @function statvfs
 @string path any path within the mounted file system
-@treturn PosixStatvfs information about file system containing *path*
+@treturn[1] PosixStatvfs information about file system containing *path*, if successful
+@return[2] nil
+@treturn[2] string error message
+@treturn[2] int errnum
 @see statvfs(3)
 @usage
   local statvfs = require "posix.sys.statvfs".statvfs
